# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-08 19:12
from __future__ import unicode_literals

from django.db import migrations, models
import djfiles.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(unique=True)),
                ('mime_type', models.CharField(blank=True, max_length=128, null=True)),
                ('content', models.FileField(upload_to=djfiles.models.file_upload_to)),
                ('description', models.TextField(blank=True, null=True)),
            ],
            options={
                'db_table': 'files',
                'verbose_name': '\u0444\u0430\u0439\u043b',
                'verbose_name_plural': '\u0444\u0430\u0439\u043b\u044b',
            },
        ),
    ]
